@@ -19,8 +19,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
 #include <pango-attributes.h>
 #include <pango-item.h>
+#include <pango-utils.h>
 
 /**
  * pango_item_new:
@@ -32,7 +34,7 @@
 PangoItem *
 pango_item_new (void)
 {
-  PangoItem *result = g_new0 (PangoItem, 1);
+  PangoItem *result = g_slice_new0 (PangoItem);
 
   return result;
 }
@@ -49,7 +51,7 @@ PangoItem *
 pango_item_copy (PangoItem *item)
 {
   GSList *extra_attrs, *tmp_list;
-  PangoItem *result = g_new (PangoItem, 1);
+  PangoItem *result = g_slice_new (PangoItem);
 
   result->offset = item->offset;
   result->length = item->length;
@@ -90,7 +92,7 @@ pango_item_free (PangoItem *item)
   if (item->analysis.font)
     g_object_unref (item->analysis.font);
 
-  g_free (item);
+  g_slice_free (PangoItem, item);
 }
 
 GType
@@ -99,7 +101,7 @@ pango_item_get_type (void)
   static GType our_type = 0;
   
   if (our_type == 0)
-    our_type = g_boxed_type_register_static ("PangoItem",
+    our_type = g_boxed_type_register_static (I_("PangoItem"),
                                              (GBoxedCopyFunc) pango_item_copy,
                                              (GBoxedFreeFunc) pango_item_free);
   return our_type;
